Crate beetmash_template
beetmash_
template
0.0.7
All Items
Crate Items
Functions
Crate
beetmash_
template
Functions

base_
app_
plugin
In scene-based workflows apps are mainly for adding plugins and systems. They should only spawn low-level entities and resources, allowing for scenes to be spawned via some IO mechanism, ie cli, fs or network.